@@ -325,7 +325,7 @@ class Shvar(RememberInstanceCreationInfo):
         return self
     
 
-    def simpleuf(self, *args):
+    def simpleuf(self, *args, epdf='rec', ec=0):
         """
         A method making an ufloat type variable.
         
@@ -345,19 +345,26 @@ class Shvar(RememberInstanceCreationInfo):
         # 숫자 2개가 들어오면 uf를 반환
         # uf를 입력받으면 평균과 표준편차를 반환
         Shvar.nonwrite_init(self)
+        if epdf == 'rec':  # Error Probability Distribution Function Check
+            if isinstance(ec, (int, float)) and ec >= 0:
+                self.tbe = ec / np.sqrt(3)
+            else:
+                raise TypeError("Parameter 'ec' should be a positive number.")
+        else:
+            raise TypeError("%s is not available 'epdf'."%(epdf))
         if len(args) == 1:
             if str(type(args[0])) not in UFlist:
                 raise TypeError("The argument should be an ufloat value.")
             else:
                 a = args[0]
                 self.mean = a.n
-                self.SE = a.s
-                self.uf = a
+                self.SE = np.sqrt(a.s**2 + self.tbe**2)
+                self.uf = ufloat(self.mean, self.SE)
                 self.tp = 'uf'
         elif len(args) == 2:
             if isinstance(args[0], (int, float)) and isinstance(args[1], (int, float)):
                 self.mean = args[0]
-                self.SE = args[1]
+                self.SE = np.sqrt(args[1]**2 + self.tbe**2)
                 self.uf = ufloat(self.mean, self.SE)
                 self.tp = 'uf'
             else:
@@ -368,7 +375,7 @@ class Shvar(RememberInstanceCreationInfo):
         return self
     
     
-    def simpleuflist(self, *args):
+    def simpleuflist(self, *args, epdf='rec', ec=0):
         """
         A method making an ufloat type variable.
         
@@ -392,14 +399,22 @@ class Shvar(RememberInstanceCreationInfo):
             except TypeError:
                 raise TypeError("The arguments should be one or two lists.")
         Shvar.nonwrite_init(self)
+        if epdf == 'rec':  # Error Probability Distribution Function Check
+            if isinstance(ec, (int, float)) and ec >= 0:
+                self.tbe = ec / np.sqrt(3)
+            else:
+                raise TypeError("Parameter 'ec' should be a positive number.")
+        else:
+            raise TypeError("%s is not available 'epdf'."%(epdf))
         if len(args) == 1:
             for x in args[0]:
                 if str(type(x)) not in UFlist:
                     raise TypeError("The argument should be a list of ufloats.")
             self.uf = args[0]
             self.mean = [x.n for x in args[0]]
-            self.SE = [x.s for x in args[0]]
+            self.SE = [np.sqrt(x.s**2 + self.tbe**2) for x in args[0]]
             self.tp = 'uflist'
+            self.length = len(self.uf)
         elif len(args) == 2:
             if len(args[0]) != len(args[1]):
                 raise TypeError("The two arguments should have same length.")
@@ -409,9 +424,9 @@ class Shvar(RememberInstanceCreationInfo):
             for y in args[1]:
                 if (isinstance(y, (int, float)) and y > 0) is False:
                     raise TypeError("The second argument(SE) should be a list of positive numbers.")
-            self.uf = [ufloat(args[0][i], args[1][i]) for i in range(len(args[0]))]
             self.mean = args[0]
-            self.SE = args[1]
+            self.SE = [np.sqrt(s**2 + self.tbe**2) for s in args[1]]
+            self.uf = [ufloat(self.mean[i], self.SE[i]) for i in range(len(args[0]))]
             self.tp = 'uflist'
             self.length = len(self.uf)
         else:
