@@ -133,7 +133,8 @@ class superplt():
     def plot_comp(relation, fitxnum=1001, Title=None, pos_leg='right',
                   Label=['normal', 'normal'], Capsize=3, FMT='-o', MS=5,
                   datagraphname=None, canvascolor='white', backcolor='white',
-                  text=True, fitcolor=(0.1, 0.1, 0.1, 0.9), datacolor='black'):
+                  text=True, fitcolor=(0.1, 0.1, 0.1, 0.9), datacolor='black', 
+                  DPI=None, FIGSIZE=None, fit=True):
 
 
         """
@@ -191,7 +192,7 @@ class superplt():
             Yn = copy(relation.XYdata[1])
             YERR = None
 
-        fig = plt.figure()  # 캔버스 생성
+        fig = plt.figure(dpi=DPI, figsize=FIGSIZE)  # 캔버스 생성
         fig.set_facecolor(canvascolor)  # 캔버스 색상 설정
         ax = fig.add_subplot()  # 프레임(그림 뼈대) 생성
         ax.set_facecolor(backcolor)  # 그래프 영역 배경 색상 설정
@@ -213,7 +214,8 @@ class superplt():
             endx = 0.1 * (maxx - minx) + maxx
             fitX = np.linspace(firstx, endx, fitxnum)
             fitY = [fitting_func(x) for x in fitX]
-            ax.plot(fitX, fitY, label='linear regression', color=fitcolor)
+            if fit is True:
+                ax.plot(fitX, fitY, label='linear regression', color=fitcolor)
 
             # 피팅 결과은 식으로도 보여주게 되는데, 텍스트로 보여준다.
                 # 텍스트의 위치는 데이터의 90%, 80%, 70% 위치 또는
@@ -221,7 +223,7 @@ class superplt():
             minY = min(fitY)
             maxY = max(fitY)
             posx = minx + 0.65 * (maxx - minx)  # 텍스트가 오른쪽 방면에 쓰여질 때의 x좌표이다.
-            if text is True:
+            if text is True and fit is True:
                 if relation.slope.n >= 0:  # 기울기가 양수일 때
                     if pos_leg == 'right':  # 범례가 오른쪽일 때
                         firstposy = minY + 0.9 * (maxY - minY)
